#
# spec file for package notary
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define goipath github.com/theupdateframework/notary

Name:           notary
Version:        0.7.0
Release:        1.17
Summary:        Trusted collections handling: server and signer
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/theupdateframework/notary
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        server-config.postgres.json
Source3:        signer-config.postgres.json
Patch0:         0001-Hide-DB-credentials.patch
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.15

%description
The Notary project comprises a server and a client for running and
interacting with trusted collections.

%prep
%setup -q -n %{name}-%{version} -a 1
%patch0 -p1

%build
%goprep %{goipath}
export CGO_ENABLED=0
%define ldflags "-w -X %{goipath}/version.NotaryVersion=v%{version} -X  %{goipath}/version.GitCommit=%{release}"
%define buildtags "pkcs11"

%gobuild -mod vendor -ldflags %{ldflags} -tags %{buildtags} cmd/notary-server
%gobuild -mod vendor -ldflags %{ldflags} -tags %{buildtags} cmd/notary-signer

%install
%goinstall

install -Dm 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/notary/server-config.postgres.json
install -Dm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/notary/signer-config.postgres.json

mkdir -p %{buildroot}%{_localstatedir}/lib/notary/migrations
mkdir -p %{buildroot}%{_localstatedir}/lib/notary/migrations/server/postgresql
mkdir -p %{buildroot}%{_localstatedir}/lib/notary/migrations/signer/postgresql
install -Dpm 0755 migrations/migrate.sh %{buildroot}%{_localstatedir}/lib/notary/migrations/migrate.sh
install -Dpm 0644 migrations/server/postgresql/* %{buildroot}%{_localstatedir}/lib/notary/migrations/server/postgresql/
install -Dpm 0644 migrations/signer/postgresql/* %{buildroot}%{_localstatedir}/lib/notary/migrations/signer/postgresql/

%files
%license LICENSE
%doc README.md
%{_bindir}/notary-server
%{_bindir}/notary-signer
%config %{_sysconfdir}/notary
%{_localstatedir}/lib/notary

%config(noreplace) %{_sysconfdir}/notary/server-config.postgres.json
%config(noreplace) %{_sysconfdir}/notary/signer-config.postgres.json

%changelog
* Thu Jun 10 2021 dmueller@suse.com
- Update to version 0.7.0:
  * Add Changelog for v0.7.0 release
  * update golang.org/x/crypto and replace use of deprecated terminal package
  * cleanup tempfiles for sqlite_test
  * Add some unit tests for tuf/utils/utils.go This PR is about adding some unit tests for tuf/utils/utils.go.
  * cleanup tempfiles for integration_test
  * cleanup tempfiles for client_test
  * linting: fix Implicit memory aliasing in RangeStmt
  * Fix typos
  * CircleCI: run jobs in parallel
  * Update gorethink from v3 to v6 and rename to proper rethinkdb-go package
  * Fix some testing issues
  * Update go mod vendor for 1.14.1
  * Update Go to 1.14.1
  * Remove vendor.conf as it is no longer used
  * Fix gosec linting errors (fix G306 and G307)
  * Apply 'go mod tidy && go mod vendor'
  * Set default go flag to use -mod=vendor for cli commands
  * Make the validate-vendor.sh script solely to work with go mod
  * Align golang-cross docker image version
  * Add documentation on how to upgrade
  * Include vendor check in circleci workflow
  * Add vendor validation script to ensure deps are properly vendored after upgrade
  * Update documentation for module compatibility
  * Update docker images to use Go Modules and 1.12.15
  * Apply 'go mod vendor' (adds indirect dependencies)
  * Apply 'go mod download'
  * Apply 'go mod init github.com/theupdateframework/notary'
  * Bump mariadb from 10.1.28 to 10.4
  * Remove duplicated words
  * Update docker/distribution to 2.7.1
  * Makefile: disable debug to make CI more readable
  * CircleCI: update image, and use BuildKit
  * Update Golang 1.12.12 (CVE-2019-17596)
  * Bump golang 1.12.10 (CVE-2019-9512, CVE-2019-9514, CVE-2019-16276)
  * Update and pin golang-migrate to v4.6.2
  * Use golang-migrate/migrate, because mattes/migrate was archived
  * Fix gosec linter results not being printed
  * Fix "make test" broken on Go 1.13
  * gosec: ignore  G108: Profiling endpoint automatically exposed
  * Correct spelling mistakes.
  * bump miekg/pkcs11 v1.0.2
  * Add --version flags
  * Add Go version to version information
  * bump github.com/miekg/pkcs11 553cfdd26aaafe851ca66a5e8015f0decb6b5a1e
  * bump github.com/BurntSushi/toml v0.3.1
  * bump github.com/pkg/errors v0.8.1
  * Bump gorilla/mux to 1.7.0
  * bump sirupsen/logrus v1.4.1
  * Cleanup vendor.conf, fix mixed tabs/spaces
  * re-vendor with current version of vndr
  * cleanup: help message words correction in keys.go
  * Remove the duplicated words in code comments
  * Call flag.Parse() in testing.
  * Update Go to 1.12.7
  * Fix algorithm case handling (fix #1471)
  * Fix `FileMeta.Equals`.
  * README: fix typo
  * Regenerate test certs
  * Update pkcs#11 library
  * Replacing 'HTTP' by 'HTTPS' for securing links
  * Fix many typos Signed-off-by: Vu Cong Tuan <tuanvc@vn.fujitsu.com>
  * Update to Go 1.11.5
  * Update to Go 1.11.2
  * Switch to dockercore/golang-cross image for cross-compiling
  * Remove duplicated words in comments
  * Update deprecated links Signed-off-by: Vu Cong Tuan <tuanvc@vn.fujitsu.com>
  * client: fix logger format types for variables
  * testutils: reduce dependency on testify package in testutils
  * Update to Go 1.10.8
  * Do not check Go version user is building with
  * Fix golint as its location has moved
  * Attempt to fix Ying's circleci 2.0 upgrade
  * Refactor the notary client library to have a separate reader and downloader that may be easier to use for clients that do not need any publishing capabilities.
  * Add import of sha1 to gosec whitelist
  * Add security audit
  * Add Justin Cormack to Maintainers
  * github.com/GoASTScanner/gas has been renamed to github.com/securego/gosec, and the executable also renamed gosec.  Fix all the imports/installs so that CI works again.
  * Minor punctuation correction in README.md
  * Fix small typo
  * Bump Golang to 1.10.3
  * Do not leak cancellations for contexts
  * Remove use of distributions old wrapped context
  * Update prometheus vendoring to match distribution
  * Add docker/go-metrics vendor
  * Update docker/distribution
  * Update instructions for getting gas
  * Remove roadmap file that has no useful information
  * Update to Go 1.10.2
  * Update test certificates
  * Fix gorethink
  * Fix file creation permissions
  * Use os.Open not os.OpenFile(..., os.O_RDONLY, ...)
  * Remove baseDir from NewRepository
  * Update vendoring for x/crypto and remove agl/ed25519
  * Use golang/x/crypto for ed25519
  * Temporarily disable two gas rules
  * Add gas output to .gitignore
  * Mark the inclusion of md5 in fips.go as ignore by gas
  * Re-enable gas AST Scanner
  * Add another note about serialization of ed25519 keys
  * Add the CNCF Code of Conduct
* Mon Sep  7 2020 Jiri Suchomel <jsuchome@suse.com>
- Added 0001-Hide-DB-credentials.patch:
  - modify the log message from notary tool to make sure the DB URL
  (incl. password) is not displayed
  - based on https://github.com/goharbor/harbor/pull/9511
* Tue Sep  1 2020 jsuchome@suse.com
- initial release
